﻿using System;
using System.Collections.Generic;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace Mvc_Projection32149Sample.Controllers
{
    public class HomeController : Controller
    {
        // GET: Home
        public ActionResult Index()
        {
            var map = GetSampleMap();
            return View(map);
        }

        public Map GetSampleMap()
        {
            //Setup a map canvas
            Map sampleMap = new Map("SampleMap",
                     new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage), 500);
            sampleMap.MapBackground = new BackgroundLayer(new GeoSolidBrush(GeoColor.StandardColors.White));

            Uri serverUri = new Uri("http://sampleserver1.arcgisonline.com/ArcGIS/rest/services/Specialty/ESRI_StateCityHighway_USA/MapServer/export");
            ArcGISServerRestOverlay overlay = new ArcGISServerRestOverlay("sampleId", serverUri);
            overlay.Parameters.Add("format", "jpeg");

            // Sets the projection to EPSG: 32149
            overlay.Projection = "EPSG:32149";

            sampleMap.CurrentExtent = new RectangleShape(187754.6365, 259585.0321, 781043.7173, 30497.7688);  //32149 projection boundaries in meters
            sampleMap.MapUnit = GeographyUnit.Meter;


            LayerOverlay layerOverlay = new LayerOverlay("DynamicOverlay");
            layerOverlay.Layers.Add(AddMidPointCircle());

            // Adds a ShapeFileFeatureLayer to determine whether the base map.
            layerOverlay.Layers.Add(AddShapeFileFeatureLayer());

            // Adds the ArcGISServerRestOverlay and LayerOverlay into CustomOverlays.
            sampleMap.CustomOverlays.Add(overlay);
            sampleMap.CustomOverlays.Add(layerOverlay);


            //// The ArcGISServerRestOverlay is base overlay. 
            //// The StaticOverlay is a shortcut way for you to add a LayerOverlay to the map. It can only be the base overlay.
            //// The map can contain multiple base overlays, though only one of them can be displayed at a time.
           
            //sampleMap.CustomOverlays.Add(overlay);
            //sampleMap.StaticOverlay.Layers.Add(AddMidPointCircle());
            //sampleMap.StaticOverlay.Layers.Add(AddShapeFileFeatureLayer());


            return sampleMap;
        }

        public ShapeFileFeatureLayer AddShapeFileFeatureLayer()
        {
            ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/USStates.shp"));
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(GeoPens.Black, new GeoSolidBrush(new GeoColor(150, GeoColor.SimpleColors.BrightOrange)));
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Sets the projection of ShapeFileFeatureLayer to 32149.
            Proj4Projection proj4 = new Proj4Projection(4326, 32149);
            proj4.Open();
            shapeFileFeatureLayer.FeatureSource.Projection = proj4;

            return shapeFileFeatureLayer;
        }

        public InMemoryFeatureLayer AddMidPointCircle()
        {
            InMemoryFeatureLayer midPointLayer = new InMemoryFeatureLayer();
            midPointLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle =
                new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(new GeoColor(50, GeoColor.GeographicColors.DeepOcean)),
                new GeoPen(GeoColor.GeographicColors.DeepOcean), 20);
            midPointLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Feature circleInWashington = new Feature(new Vertex(-119.6, 46.55), "MidPoint", new Dictionary<string, string>());

            // Convert the feature to 32149.
            Proj4Projection proj4 = new Proj4Projection(4326, 32149);
            proj4.Open();
            circleInWashington = proj4.ConvertToExternalProjection(circleInWashington);

            midPointLayer.Open();
            midPointLayer.FeatureSource.BeginTransaction();
            midPointLayer.FeatureSource.AddFeature(circleInWashington);
            midPointLayer.FeatureSource.CommitTransaction();
            midPointLayer.Close();

            return midPointLayer;
        }

    }
}